#!/usr/bin/python3

import pymysql
import os

def make_umls_mrsty(mysql_info,save_path="umls_sty_rels.csv",save_folder=""):
    if save_folder!="":
        save_path=os.path.join(save_folder,save_path)
    # open db connection
    db = pymysql.connect(host=mysql_info["hostname"], user=mysql_info["username"], password=mysql_info["password"], database=mysql_info["database"])

    cursor = db.cursor()

    sql = "SELECT * from mrsty"
    sql_count = "SELECT count(*) from mrsty"

    # write file
    header = ":START_ID,:END_ID,:TYPE,CUI,TUI,STN,STY,ATUI,CVF\n"

    fo = open(save_path, 'w', encoding='utf-8')

    cursor.execute(sql_count)
    count = cursor.fetchone()[0]
    batch_size = 20 * 10000  # whatever

    counter = 0
    fo.write(header)
    for offset in range(0, count, batch_size):
        cursor.execute(sql + " LIMIT %s OFFSET %s", (batch_size, offset))

        # obtain a list of column names
        cols = cursor.description
        list_cols = []
        for i in range(len(cols)):
            list_cols.append(cols[i][0])
        # print(list_cols)

        for row in cursor:
            # ID
            CUI = row[list_cols.index('CUI')]
            TUI = row[list_cols.index('TUI')]
            STN = row[list_cols.index('STN')]
            STY = row[list_cols.index('STY')].replace("\"", "'")
            ATUI = row[list_cols.index('ATUI')]
            CVF = row[list_cols.index('CVF')]

            if CVF == None:
                CVF = ""

            # print results
            line = str(CUI) + "," + str(TUI) + ",\"" + str("HAS_SR") + "\",\"" + str(CUI) + "\",\"" + str(
                TUI) + "\",\"" + str(STN) + "\",\"" + str(STY) + "\",\"" + \
                   str(ATUI) + "\",\"" + str(CVF) + "\""
            # print(line)
            fo.write(line + "\n")
            counter = counter + 1
        print('counter = ' + str(counter))

    fo.close()

    # close connection
    db.close()


#!/usr/bin/python3

import pymysql
import os
def make_umls_srdef(mysql_info,save_path="umls_sr_nodes.csv",save_folder=""):
    if save_folder!="":
        save_path=os.path.join(save_folder,save_path)
    # open db connection
    db = pymysql.connect(host=mysql_info["hostname"], user=mysql_info["username"], password=mysql_info["password"], database=mysql_info["database"])

    cursor = db.cursor()

    sql = "SELECT * FROM srdef"
    sql_count = "SELECT count(*) FROM srdef"

    # write file
    header = ":ID,:LABEL,UI,RT,STY_RL,STN_RTN,DEF,EX,UN,NH,ABR,RIN\n"

    fo = open(save_path, 'w', encoding='utf-8')

    cursor.execute(sql_count)
    count = cursor.fetchone()[0]

    print("total record count: " + str(count))

    batch_size = 10 * 10000  # whatever

    counter = 0
    fo.write(header)
    for offset in range(0, count, batch_size):
        cursor.execute(sql + " LIMIT %s OFFSET %s", (batch_size, offset))

        # obtain a list of column names
        cols = cursor.description
        list_cols = []
        for i in range(len(cols)):
            list_cols.append(cols[i][0])
        print(list_cols)

        for row in cursor:
            # ID
            RT = row[list_cols.index('RT')]
            # Label
            UI = row[list_cols.index('UI')]
            STY_RL = row[list_cols.index('STY_RL')]
            STN_RTN = row[list_cols.index('STN_RTN')]
            DEF = row[list_cols.index('DEF')].replace("\"", "'")
            EX = row[list_cols.index('EX')]
            UN = row[list_cols.index('UN')]
            NH = row[list_cols.index('NH')]
            ABR = row[list_cols.index('ABR')]
            RIN = row[list_cols.index('RIN')]
            print(row)

            if EX == None:
                EX = ""
            if UN == None or UN == 'NULL':
                UN = ""
            if NH == None:
                NH = ""
            if ABR == None:
                ABR = ""
            if RIN == None:
                RIN = ""
            if RT == None:
                RT = ""
            if STY_RL == None:
                STY_RL = ""
            if STN_RTN == None:
                STN_RTN = ""
            if DEF == None:
                DEF = ""
            if UI == None:
                UI = ""

            UN = UN.replace("\"", "'")

            # print(UI,RT,STY_RL,STN_RTN,DEF,EX,UN+","+NH+","+ABR+","+RIN)
            print(EX)

            line = UI + "," + RT + ",\"" + STY_RL + "\",\"" + STN_RTN + "\",\"" + DEF + "\",\"" + EX + "\",\"" + UN + "\",\"" + NH + "\",\"" + ABR + "\",\"" + RIN + "\""
            fo.write(line + "\n")

            counter = counter + 1
        print('counter = ' + str(counter))

    fo.close()

    # close connection
    db.close()


#!/usr/bin/python3

import pymysql
import os

def make_umls_mrsmap(mysql_info,save_path_rels="umls_smap_rels.csv",save_path_nodes="umls_smap_nodes.csv",save_folder=""):
    if save_folder!="":
        save_path_rels=os.path.join(save_folder,save_path_rels)
        save_path_nodes = os.path.join(save_folder, save_path_nodes)

    # open db connection
    db = pymysql.connect(host=mysql_info["hostname"], user=mysql_info["username"], password=mysql_info["password"], database=mysql_info["database"])

    cursor = db.cursor()

    sql = "SELECT * from mrsmap"
    sql_count = "SELECT count(*) from mrsmap"

    # write file
    header = ":START_ID,:END_ID,:TYPE,MAPSETCUI,MAPSETSAB,MAPID,MAPSID,FROMEXPR,FROMTYPE,REL,RELA,TOEXPR,TOTYPE,CVF\n"
    header_n = ":ID,:LABEL,EXPR,EXPR_TYPE\n"

    fo = open(save_path_rels, 'w', encoding='utf-8')
    fo_n = open(save_path_nodes, 'w', encoding='utf-8')

    cursor.execute(sql_count)
    count = cursor.fetchone()[0]
    batch_size = 20 * 10000  # whatever

    print("total record count: " + str(count))

    dict_expr = {}

    counter = 0
    fo.write(header)
    fo_n.write(header_n)
    for offset in range(0, count, batch_size):
        cursor.execute(sql + " LIMIT %s OFFSET %s", (batch_size, offset))

        # obtain a list of column names
        cols = cursor.description
        list_cols = []
        for i in range(len(cols)):
            list_cols.append(cols[i][0])
        # print(list_cols)

        for row in cursor:
            # ID

            MAPSETCUI = row[list_cols.index('MAPSETCUI')]
            MAPSETSAB = row[list_cols.index('MAPSETSAB')]
            MAPID = row[list_cols.index('MAPID')]
            MAPSID = row[list_cols.index('MAPSID')]
            FROMEXPR = row[list_cols.index('FROMEXPR')]
            FROMTYPE = row[list_cols.index('FROMTYPE')]
            REL = row[list_cols.index('REL')]
            RELA = row[list_cols.index('RELA')]
            TOEXPR = row[list_cols.index('TOEXPR')]
            TOTYPE = row[list_cols.index('TOTYPE')]
            CVF = row[list_cols.index('CVF')]

            if CVF == None:
                CVF = ""
            if MAPSID == None:
                MAPSID = ""

            # print results
            line = "\"" + str(FROMEXPR) + "\",\"" + str(TOEXPR) + "\",\"" + str("SMAP") + "\",\"" + str(
                MAPSETCUI) + "\",\"" + str(MAPSETSAB) + "\",\"" + MAPID + "\",\"" + MAPSID + "\",\"" \
                   + str(FROMEXPR) + "\",\"" + str(FROMTYPE) + "\",\"" + str(REL) + "\",\"" + str(RELA) + "\",\"" + str(
                TOEXPR) + "\",\"" + str(TOTYPE) + "\",\"" + str(CVF) + "\""
            # print(line)
            fo.write(line + "\n")

            # line2=str(FROMEXPR)+","+str("MapEntity")+",\""+str(FROMEXPR)+"\""
            # fo_n.write(line2+"\n")

            if FROMTYPE != "CUI" and not dict_expr.keys().__contains__(FROMEXPR):
                line2 = "\"" + str(FROMEXPR) + "\"," + str("MapEntity") + ",\"" + str(
                    FROMEXPR) + "\",\"" + FROMTYPE + "\""
                fo_n.write(line2 + "\n")
                dict_expr[FROMEXPR] = FROMTYPE
            if TOTYPE != "CUI" and not dict_expr.keys().__contains__(TOEXPR):
                line2 = "\"" + str(TOEXPR) + "\"," + str("MapEntity") + ",\"" + str(TOEXPR) + "\",\"" + TOTYPE + "\""
                fo_n.write(line2 + "\n")
                dict_expr[TOEXPR] = TOTYPE

            counter = counter + 1
        print('counter = ' + str(counter))

    fo.close()
    fo_n.close()

    # close connection
    db.close()


#!/usr/bin/python3

import pymysql
import os

def make_umls_mrconso(mysql_info,save_path="umls_aui_nodes.csv",save_folder=""):
    if save_folder!="":
        save_path=os.path.join(save_folder,save_path)

    # open db connection
    db = pymysql.connect(host=mysql_info["hostname"], user=mysql_info["username"], password=mysql_info["password"], database=mysql_info["database"])

    cursor = db.cursor()

    sql = "SELECT * from mrconso"
    sql_count = "SELECT count(*) from mrconso"

    # write file
    header = ":ID,:LABEL,SAB,CUI,LUI,SUI,STR,AUI,TTY,CODE,SRL,SUPPRESS,CVF,SAUI,SCUI,SDUI,ISPREF,LAT,TS\n"

    fo = open(save_path, 'w', encoding='utf-8')

    cursor.execute(sql_count)
    count = cursor.fetchone()[0]
    batch_size = 10 * 10000  # whatever

    counter = 0
    fo.write(header)
    for offset in range(0, count, batch_size):
        cursor.execute(sql + " LIMIT %s OFFSET %s", (batch_size, offset))

        # obtain a list of column names
        cols = cursor.description
        list_cols = []
        for i in range(len(cols)):
            list_cols.append(cols[i][0])
        print(list_cols)

        for row in cursor:
            # ID
            ID = row[list_cols.index('AUI')]
            # Label
            SAB = row[list_cols.index('SAB')]
            label = "Atom"

            # Properties
            CUI = row[list_cols.index('CUI')]
            LUI = row[list_cols.index('LUI')]
            AUI = row[list_cols.index('AUI')]
            SUI = row[list_cols.index('SUI')]
            TTY = row[list_cols.index('TTY')]
            CODE = row[list_cols.index('CODE')]
            SRL = row[list_cols.index('SRL')]
            SUPPRESS = row[list_cols.index('SUPPRESS')]
            CVF = row[list_cols.index('CVF')]
            SAUI = row[list_cols.index('SAUI')]
            SCUI = row[list_cols.index('SCUI')]
            SDUI = row[list_cols.index('SDUI')]
            ISPREF = row[list_cols.index('ISPREF')]
            LAT = row[list_cols.index('LAT')]
            TS = row[list_cols.index('TS')]

            if SAUI == None:
                SAUI = ''
            if SCUI == None:
                SCUI = ''
            if SDUI == None:
                SDUI = ''
            if TS == None:
                TS = ""
            if LAT == None:
                LAT = ""

            STR = row[list_cols.index('STR')].replace("\"", "'")

            # pring results
            line = ID + "," + label + "," + SAB + "," + CUI + "," + LUI + "," + SUI + ",\"" + STR + "\"," + AUI + ",\"" \
                   + TTY + "\",\"" + str(CODE) + "\",\"" + str(SRL) + "\",\"" + SUPPRESS + "\",\"" + str(
                CVF) + "\",\"" + str(SAUI) + "\",\"" + str(SCUI) + "\",\"" + str(SDUI) + "\",\"" + str(
                ISPREF) + "\",\"" + str(LAT) + "\",\"" + str(TS) + "\""
            # print(line)
            fo.write(line + "\n")
            counter = counter + 1
        print('counter = ' + str(counter))

    fo.close()

    # close connection
    db.close()


#!/usr/bin/python3

import pymysql
import os
def make_umls_mrrel(mysql_info,save_path="umls_rels.csv",save_folder=""):
    if save_folder!="":
        save_path=os.path.join(save_folder,save_path)

    # open db connection
    db = pymysql.connect(host=mysql_info["hostname"], user=mysql_info["username"], password=mysql_info["password"], database=mysql_info["database"])

    cursor = db.cursor()

    sql = "SELECT * from mrrel"
    sql_count = "SELECT count(*) from mrrel"

    # write file
    header = ":START_ID,:END_ID,:TYPE,RELA,RUI,SAB,SL,RG,STYPE1,STYPE2,SRUI,SUPPRESS,CVF\n"

    fo = open(save_path, 'w', encoding='utf-8')

    cursor.execute(sql_count)
    count = cursor.fetchone()[0]
    batch_size = 20 * 10000  # whatever

    counter = 0
    fo.write(header)
    for offset in range(0, count, batch_size):
        cursor.execute(sql + " LIMIT %s OFFSET %s", (batch_size, offset))

        # obtain a list of column names
        cols = cursor.description
        list_cols = []
        for i in range(len(cols)):
            list_cols.append(cols[i][0])
        # print(list_cols)

        for row in cursor:
            # ID
            CUI1 = row[list_cols.index('CUI1')]
            CUI2 = row[list_cols.index('CUI2')]
            AUI1 = row[list_cols.index('AUI1')]
            AUI2 = row[list_cols.index('AUI2')]
            STYPE1 = row[list_cols.index('STYPE1')]
            STYPE2 = row[list_cols.index('STYPE2')]
            start_node = CUI1
            end_node = CUI2
            if STYPE1 == 'AUI':
                start_node = AUI1
            if STYPE2 == 'AUI':
                end_node = AUI2
            if AUI1 == None:
                start_node = CUI1
            if AUI2 == None:
                end_node = CUI2

            REL = row[list_cols.index('REL')]
            RELA = row[list_cols.index('RELA')]
            RUI = row[list_cols.index('RUI')]
            SAB = row[list_cols.index('SAB')]
            SL = row[list_cols.index('SL')]
            RG = row[list_cols.index('RG')]

            SRUI = row[list_cols.index('SRUI')]
            SUPPRESS = row[list_cols.index('SUPPRESS')]
            CVF = row[list_cols.index('CVF')]

            if SRUI == None:
                SRUI = ""
            if SUPPRESS == None:
                SUPPRESS = ""
            if CVF == None:
                CVF = ""

            if SAB == None:
                SAB = ""
            if RUI == None:
                RUI = ""
            if REL == None:
                REL = ""
            if SL == None:
                SL = ""
            if RG == None:
                RG = ""
            if RELA == None:
                RELA = ""

            # print results
            line = str(start_node) + "," + str(end_node) + ",\"" + str(REL) + "\",\"" + str(RELA) + "\",\"" + str(
                RUI) + "\",\"" + str(SAB) + "\",\"" + str(SL) + "\",\"" + \
                   RG + "\",\"" + STYPE1 + "\",\"" + STYPE2 + "\",\"" + str(SRUI) + "\",\"" + str(
                SUPPRESS) + "\",\"" + str(CVF) + "\""
            # print(line)
            fo.write(line + "\n")
            counter = counter + 1
        print('counter = ' + str(counter))

    fo.close()

    # close connection
    db.close()


#!/usr/bin/python3

import pymysql
import os

def make_umls_mrsat(mysql_info,save_path_rels="umls_rels.csv",save_path_nodes="umls_atui_nodes.csv",save_folder=""):
    if save_folder!="":
        save_path_rels=os.path.join(save_folder,save_path_rels)
        save_path_nodes = os.path.join(save_folder, save_path_nodes)

    # open db connection
    db = pymysql.connect(host=mysql_info["hostname"], user=mysql_info["username"], password=mysql_info["password"], database=mysql_info["database"])

    cursor = db.cursor()

    sql = "SELECT * from mrsat"
    sql_count = "SELECT count(*) from mrsat"

    # write file
    header = ":START_ID,:END_ID,:TYPE\n"
    header_n = ":ID,:LABEL,ATUI,SATUI,ATN,SAB,ATV,SUPPRESS,CVF\n"

    fo = open(save_path_rels, 'w', encoding='utf-8')
    fo_n = open(save_path_nodes, 'w', encoding='utf-8')

    cursor.execute(sql_count)
    count = cursor.fetchone()[0]
    batch_size = 20 * 10000  # whatever

    print("total record count: " + str(count))

    counter = 0
    fo.write(header)
    fo_n.write(header_n)
    for offset in range(0, count, batch_size):
        cursor.execute(sql + " LIMIT %s OFFSET %s", (batch_size, offset))

        # obtain a list of column names
        cols = cursor.description
        list_cols = []
        for i in range(len(cols)):
            list_cols.append(cols[i][0])
        # print(list_cols)

        for row in cursor:
            # ID
            CUI = row[list_cols.index('CUI')]
            LUI = row[list_cols.index('LUI')]
            SUI = row[list_cols.index('SUI')]
            METAUI = row[list_cols.index('METAUI')]
            STYPE = row[list_cols.index('STYPE')]
            CODE = row[list_cols.index('CODE')]
            ATUI = row[list_cols.index('ATUI')]
            SATUI = row[list_cols.index('SATUI')]
            ATN = row[list_cols.index('ATN')]
            SAB = row[list_cols.index('SAB')]
            ATV = row[list_cols.index('ATV')].replace("\"", "'")
            SUPPRESS = row[list_cols.index('SUPPRESS')]
            CVF = row[list_cols.index('CVF')]

            start_node = CUI
            if STYPE == 'CUI':
                start_node = CUI
            if STYPE == "AUI" or STYPE == "RUI" or STYPE == "SDUI" or STYPE == "SCUI":
                start_node = METAUI
            if STYPE == "CODE":
                start_node = CODE

            end_node = ATUI

            if CVF == None:
                CVF = ""
            if SUPPRESS == None:
                SUPPRESS = ""
            if SATUI == None:
                SATUI = ""

            # print results
            line = str(start_node) + "," + str(end_node) + ",\"" + str(ATN) + "\""
            # +str(ATUI)+"\",\""+str(SATUI)+"\",\""+SAB+"\",\""+ATV.replace('\"',"'")+"\",\""+str(SUPPRESS)+"\",\""+str(CVF)+"\""
            # print(line)
            fo.write(line + "\n")

            line2 = str(ATUI) + "," + str("Attribute") + ",\"" + str(ATUI) + "\",\"" + str(SATUI) + "\",\"" + str(
                ATN) + "\",\"" + str(SAB) + "\",\"" + str(ATV) + "\",\"" + str(SUPPRESS) + "\",\"" + str(CVF) + "\""
            fo_n.write(line2 + "\n")

            counter = counter + 1
        print('counter = ' + str(counter))

    fo.close()
    fo_n.close()

    # close connection
    db.close()


from umls_ambiglui import *
from umls_ambigsui import *
from umls_mrconso import *
from umls_mrconso_concept import *
from umls_mrconso_string import *
from umls_mrconso_term import *
from umls_mrdef import *
from umls_mrrel import *
from umls_mrsat import *
from umls_mrsmap import *
from umls_mrsty import *
from umls_srdef import *

def make_umls_all(save_folder,mysql_info=None):
    if mysql_info==None:
        mysql_info = {}
        mysql_info["database"] = "umls"
        mysql_info["username"] = "root"
        mysql_info["password"] = "123456"
        mysql_info["hostname"] = "localhost"

    make_umls_ambiglui(mysql_info,save_folder=save_folder)
    make_umls_ambigsui(mysql_info, save_folder=save_folder)
    make_umls_mrconso(mysql_info, save_folder=save_folder)
    make_umls_mrconso_concept(mysql_info, save_folder=save_folder)
    make_umls_mrconso_string(mysql_info, save_folder=save_folder)
    make_umls_mrconso_term(mysql_info, save_folder=save_folder)
    make_umls_mrdef(mysql_info,save_folder=save_folder)
    make_umls_mrrel(mysql_info, save_folder=save_folder)
    make_umls_mrsat(mysql_info, save_folder=save_folder)
    make_umls_mrsmap(mysql_info, save_folder=save_folder)
    make_umls_mrsty(mysql_info, save_folder=save_folder)
    make_umls_srdef(mysql_info, save_folder=save_folder)





#!/usr/bin/python3

import pymysql
import os

def make_umls_mrconso_concept(mysql_info,save_path="umls_cui_nodes.csv",save_folder=""):
    if save_folder!="":
        save_path=os.path.join(save_folder,save_path)

    # open db connection
    db = pymysql.connect(host=mysql_info["hostname"], user=mysql_info["username"], password=mysql_info["password"], database=mysql_info["database"])

    cursor = db.cursor()

    sql = "SELECT distinct CUI FROM mrconso"
    sql_count = "SELECT count(distinct CUI) FROM mrconso"

    # write file
    header = ":ID,:LABEL,CUI\n"

    fo = open(save_path, 'w', encoding='utf-8')

    cursor.execute(sql_count)
    count = cursor.fetchone()[0]

    print("total record count: " + str(count))

    batch_size = 10 * 10000  # whatever

    counter = 0
    fo.write(header)
    for offset in range(0, count, batch_size):
        cursor.execute(sql + " LIMIT %s OFFSET %s", (batch_size, offset))

        # obtain a list of column names
        cols = cursor.description
        list_cols = []
        for i in range(len(cols)):
            list_cols.append(cols[i][0])
        print(list_cols)

        for row in cursor:
            # ID
            CUI = row[list_cols.index('CUI')]
            # Label
            label = "Concept"

            # Properties

            # LAT = row[list_cols.index('LAT')]
            # TS = row[list_cols.index('TS')]

            # print results
            line = CUI + "," + label + "," + CUI
            # print(line)
            fo.write(line + "\n")
            counter = counter + 1
        print('counter = ' + str(counter))

    fo.close()

    # close connection
    db.close()
